npstructures
============

.. autosummary::
     :toctree: stubs

     npstructures.RaggedArray
     npstructures.HashTable
     npstructures.Counter
     npstructures.raggedshape.RaggedShape
     npstructures.raggedshape.RaggedView
